@@ -144,10 +144,16 @@ def url_scheme() -> str:
     return scheme
 
 
+def base_url() -> str:
+    """For convenience, returns the combination of `url_scheme()` and `domain_name()`."""
+    return f"{url_scheme()}://{domain_name()}"
+
+
 def dashboard_public() -> bool:
     """Return settings.WEBMENTIONS_DASHBOARD_PUBLIC.
 
-    Intended for"""
+    This is intended to help with debugging while developing the `django-wm`
+    library and probably should not be used otherwise."""
     is_dashboard_public = _get_attr(SETTING_DASHBOARD_PUBLIC)
     if not settings.DEBUG and is_dashboard_public:
         log.warning(
