@@ -1,8 +1,7 @@
 import logging
 from typing import Optional, Tuple
-from urllib.parse import urlsplit
+from urllib.parse import urljoin
 
-from django.conf import settings
 from django.core.exceptions import ValidationError
 from requests import RequestException, Response
 
@@ -36,7 +35,7 @@ log = logging.getLogger(__name__)
 def try_send_webmention(
     source_urlpath: str,
     target_url: str,
-    outgoing_status: Optional[OutgoingWebmentionStatus] = None,
+    outgoing_status: Optional[OutgoingWebmentionStatus],
 ) -> Optional[bool]:
     """Try to send a webmention for target_url.
 
@@ -125,7 +124,7 @@ def _send_webmention(
 ) -> Tuple[bool, int]:
     payload = {
         "target": target,
-        "source": f"{options.url_scheme()}://{settings.DOMAIN_NAME}{source_urlpath}",
+        "source": urljoin(options.base_url(), source_urlpath),
     }
     response = http_post(endpoint, data=payload)
     status_code = response.status_code
@@ -150,27 +149,21 @@ def _get_absolute_endpoint_from_response(response: Response) -> Optional[str]:
         response.text
     )
 
-    abs_url = _relative_to_absolute_url(response, endpoint)
-    log.debug(f"Absolute url: {endpoint} -> {abs_url}")
-
-    return abs_url
+    if endpoint:
+        return _relative_to_absolute_url(response, endpoint)
 
 
 def _relative_to_absolute_url(response: Response, url: str) -> Optional[str]:
     """
     If given url is relative, try to construct an absolute url using response domain.
     """
-    if not url:
-        return None
-
     try:
         get_url_validator()(url)
         return url  # url is already well-formed.
     except ValidationError:
-        scheme, domain, _, _, _ = urlsplit(response.url)
-        if not scheme or not domain:
-            return None
-        return f"{scheme}://{domain}/" f'{url if not url.startswith("/") else url[1:]}'
+        absolute_url = urljoin(response.url, url)
+        log.debug(f"Relative endpoint url resolved: {url} -> {absolute_url}")
+        return absolute_url
 
 
 def _save_for_retry(status: OutgoingWebmentionStatus, message: str) -> None:
